@@ -16,7 +16,8 @@ class CountryStateServiceApi:
 
         This operation returns all states of all countries.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True
+        asynchronous HTTP request, please pass async_req=True.
+        
         >>> thread = api.all(async_req=True)
         >>> result = thread.get()
 
@@ -26,8 +27,8 @@ class CountryStateServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-
-
+        
+        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
         if kwargs.get('async_req'):
             return self.all_with_http_info(**kwargs)
         else:
@@ -39,7 +40,8 @@ class CountryStateServiceApi:
 
         This operation returns all states of all countries.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True
+        asynchronous HTTP request, please pass async_req=True.
+        
         >>> thread = api.all_with_http_info(async_req=True)
         >>> result = thread.get()
 
@@ -53,7 +55,7 @@ class CountryStateServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('_request_timeout')
+        all_params.append('request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -101,7 +103,7 @@ class CountryStateServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('_request_timeout'),
+            _request_timeout=params.get('request_timeout'),
             collection_formats=collection_formats)
 
     def country(self, code, **kwargs):
@@ -109,7 +111,8 @@ class CountryStateServiceApi:
 
         This operation returns all states for a given country.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True
+        asynchronous HTTP request, please pass async_req=True.
+        
         >>> thread = api.country(code, async_req=True)
         >>> result = thread.get()
 
@@ -120,8 +123,8 @@ class CountryStateServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-
-
+        
+        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
         if kwargs.get('async_req'):
             return self.country_with_http_info(code, **kwargs)
         else:
@@ -133,7 +136,8 @@ class CountryStateServiceApi:
 
         This operation returns all states for a given country.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True
+        asynchronous HTTP request, please pass async_req=True.
+        
         >>> thread = api.country_with_http_info(code, async_req=True)
         >>> result = thread.get()
 
@@ -148,7 +152,7 @@ class CountryStateServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('_request_timeout')
+        all_params.append('request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -202,5 +206,5 @@ class CountryStateServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('_request_timeout'),
+            _request_timeout=params.get('request_timeout'),
             collection_formats=collection_formats)
