@@ -16,7 +16,8 @@ class MerticUsageServiceApi:
 
         Calculates the consumed resources for the given space and time range.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True
+        asynchronous HTTP request, please pass async_req=True.
+        
         >>> thread = api.calculate(space_id, start, end, async_req=True)
         >>> result = thread.get()
 
@@ -29,8 +30,8 @@ class MerticUsageServiceApi:
                  returns the request thread.
         """
         kwargs['_return_http_data_only'] = True
-
-
+        
+        kwargs['request_timeout'] = self.api_client.configuration.request_timeout
         if kwargs.get('async_req'):
             return self.calculate_with_http_info(space_id, start, end, **kwargs)
         else:
@@ -42,7 +43,8 @@ class MerticUsageServiceApi:
 
         Calculates the consumed resources for the given space and time range.
         This method makes a synchronous HTTP request by default. To make an
-        asynchronous HTTP request, please pass async_req=True
+        asynchronous HTTP request, please pass async_req=True.
+        
         >>> thread = api.calculate_with_http_info(space_id, start, end, async_req=True)
         >>> result = thread.get()
 
@@ -59,7 +61,7 @@ class MerticUsageServiceApi:
         all_params.append('async_req')
         all_params.append('_return_http_data_only')
         all_params.append('_preload_content')
-        all_params.append('_request_timeout')
+        all_params.append('request_timeout')
 
         params = locals()
         for key, val in six.iteritems(params['kwargs']):
@@ -125,5 +127,5 @@ class MerticUsageServiceApi:
             async_req=params.get('async_req'),
             _return_http_data_only=params.get('_return_http_data_only'),
             _preload_content=params.get('_preload_content', True),
-            _request_timeout=params.get('_request_timeout'),
+            _request_timeout=params.get('request_timeout'),
             collection_formats=collection_formats)
