@@ -61,7 +61,7 @@ class AbstractWebhookUrlUpdate:
     def state(self):
         """Gets the state of this AbstractWebhookUrlUpdate.
 
-            
+            The object's current state.
 
         :return: The state of this AbstractWebhookUrlUpdate.
         :rtype: CreationEntityState
@@ -72,7 +72,7 @@ class AbstractWebhookUrlUpdate:
     def state(self, state):
         """Sets the state of this AbstractWebhookUrlUpdate.
 
-            
+            The object's current state.
 
         :param state: The state of this AbstractWebhookUrlUpdate.
         :type: CreationEntityState
@@ -100,6 +100,10 @@ class AbstractWebhookUrlUpdate:
         :param url: The url of this AbstractWebhookUrlUpdate.
         :type: str
         """
+        if url is not None and len(url) > 500:
+            raise ValueError("Invalid value for `url`, length must be less than or equal to `500`")
+        if url is not None and len(url) < 9:
+            raise ValueError("Invalid value for `url`, length must be greater than or equal to `9`")
 
         self._url = url
     
