@@ -106,7 +106,7 @@ class DocumentTemplate:
     def id(self):
         """Gets the id of this DocumentTemplate.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :return: The id of this DocumentTemplate.
         :rtype: int
@@ -117,7 +117,7 @@ class DocumentTemplate:
     def id(self, id):
         """Sets the id of this DocumentTemplate.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :param id: The id of this DocumentTemplate.
         :type: int
@@ -129,7 +129,7 @@ class DocumentTemplate:
     def linked_space_id(self):
         """Gets the linked_space_id of this DocumentTemplate.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :return: The linked_space_id of this DocumentTemplate.
         :rtype: int
@@ -140,7 +140,7 @@ class DocumentTemplate:
     def linked_space_id(self, linked_space_id):
         """Sets the linked_space_id of this DocumentTemplate.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :param linked_space_id: The linked_space_id of this DocumentTemplate.
         :type: int
@@ -177,7 +177,7 @@ class DocumentTemplate:
     def planned_purge_date(self):
         """Gets the planned_purge_date of this DocumentTemplate.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :return: The planned_purge_date of this DocumentTemplate.
         :rtype: datetime
@@ -188,7 +188,7 @@ class DocumentTemplate:
     def planned_purge_date(self, planned_purge_date):
         """Sets the planned_purge_date of this DocumentTemplate.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :param planned_purge_date: The planned_purge_date of this DocumentTemplate.
         :type: datetime
@@ -223,7 +223,7 @@ class DocumentTemplate:
     def state(self):
         """Gets the state of this DocumentTemplate.
 
-            
+            The object's current state.
 
         :return: The state of this DocumentTemplate.
         :rtype: CreationEntityState
@@ -234,7 +234,7 @@ class DocumentTemplate:
     def state(self, state):
         """Sets the state of this DocumentTemplate.
 
-            
+            The object's current state.
 
         :param state: The state of this DocumentTemplate.
         :type: CreationEntityState
@@ -292,7 +292,7 @@ class DocumentTemplate:
     def version(self):
         """Gets the version of this DocumentTemplate.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :return: The version of this DocumentTemplate.
         :rtype: int
@@ -303,7 +303,7 @@ class DocumentTemplate:
     def version(self, version):
         """Sets the version of this DocumentTemplate.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :param version: The version of this DocumentTemplate.
         :type: int
