@@ -124,7 +124,7 @@ class InstallmentPlanConfiguration:
     def id(self):
         """Gets the id of this InstallmentPlanConfiguration.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :return: The id of this InstallmentPlanConfiguration.
         :rtype: int
@@ -135,7 +135,7 @@ class InstallmentPlanConfiguration:
     def id(self, id):
         """Sets the id of this InstallmentPlanConfiguration.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :param id: The id of this InstallmentPlanConfiguration.
         :type: int
@@ -193,7 +193,7 @@ class InstallmentPlanConfiguration:
     def linked_space_id(self):
         """Gets the linked_space_id of this InstallmentPlanConfiguration.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :return: The linked_space_id of this InstallmentPlanConfiguration.
         :rtype: int
@@ -204,7 +204,7 @@ class InstallmentPlanConfiguration:
     def linked_space_id(self, linked_space_id):
         """Sets the linked_space_id of this InstallmentPlanConfiguration.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :param linked_space_id: The linked_space_id of this InstallmentPlanConfiguration.
         :type: int
@@ -255,6 +255,8 @@ class InstallmentPlanConfiguration:
         :param name: The name of this InstallmentPlanConfiguration.
         :type: str
         """
+        if name is not None and len(name) > 100:
+            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")
 
         self._name = name
     
@@ -285,7 +287,7 @@ class InstallmentPlanConfiguration:
     def planned_purge_date(self):
         """Gets the planned_purge_date of this InstallmentPlanConfiguration.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :return: The planned_purge_date of this InstallmentPlanConfiguration.
         :rtype: datetime
@@ -296,7 +298,7 @@ class InstallmentPlanConfiguration:
     def planned_purge_date(self, planned_purge_date):
         """Sets the planned_purge_date of this InstallmentPlanConfiguration.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :param planned_purge_date: The planned_purge_date of this InstallmentPlanConfiguration.
         :type: datetime
@@ -354,7 +356,7 @@ class InstallmentPlanConfiguration:
     def state(self):
         """Gets the state of this InstallmentPlanConfiguration.
 
-            
+            The object's current state.
 
         :return: The state of this InstallmentPlanConfiguration.
         :rtype: CreationEntityState
@@ -365,7 +367,7 @@ class InstallmentPlanConfiguration:
     def state(self, state):
         """Sets the state of this InstallmentPlanConfiguration.
 
-            
+            The object's current state.
 
         :param state: The state of this InstallmentPlanConfiguration.
         :type: CreationEntityState
@@ -446,7 +448,7 @@ class InstallmentPlanConfiguration:
     def version(self):
         """Gets the version of this InstallmentPlanConfiguration.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :return: The version of this InstallmentPlanConfiguration.
         :rtype: int
@@ -457,7 +459,7 @@ class InstallmentPlanConfiguration:
     def version(self, version):
         """Sets the version of this InstallmentPlanConfiguration.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :param version: The version of this InstallmentPlanConfiguration.
         :type: int
