@@ -71,7 +71,7 @@ class PaymentTerminalLocation:
     def id(self):
         """Gets the id of this PaymentTerminalLocation.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :return: The id of this PaymentTerminalLocation.
         :rtype: int
@@ -82,7 +82,7 @@ class PaymentTerminalLocation:
     def id(self, id):
         """Sets the id of this PaymentTerminalLocation.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :param id: The id of this PaymentTerminalLocation.
         :type: int
@@ -94,7 +94,7 @@ class PaymentTerminalLocation:
     def linked_space_id(self):
         """Gets the linked_space_id of this PaymentTerminalLocation.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :return: The linked_space_id of this PaymentTerminalLocation.
         :rtype: int
@@ -105,7 +105,7 @@ class PaymentTerminalLocation:
     def linked_space_id(self, linked_space_id):
         """Sets the linked_space_id of this PaymentTerminalLocation.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :param linked_space_id: The linked_space_id of this PaymentTerminalLocation.
         :type: int
@@ -142,7 +142,7 @@ class PaymentTerminalLocation:
     def planned_purge_date(self):
         """Gets the planned_purge_date of this PaymentTerminalLocation.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :return: The planned_purge_date of this PaymentTerminalLocation.
         :rtype: datetime
@@ -153,7 +153,7 @@ class PaymentTerminalLocation:
     def planned_purge_date(self, planned_purge_date):
         """Sets the planned_purge_date of this PaymentTerminalLocation.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :param planned_purge_date: The planned_purge_date of this PaymentTerminalLocation.
         :type: datetime
@@ -165,7 +165,7 @@ class PaymentTerminalLocation:
     def state(self):
         """Gets the state of this PaymentTerminalLocation.
 
-            
+            The object's current state.
 
         :return: The state of this PaymentTerminalLocation.
         :rtype: PaymentTerminalLocationState
@@ -176,7 +176,7 @@ class PaymentTerminalLocation:
     def state(self, state):
         """Sets the state of this PaymentTerminalLocation.
 
-            
+            The object's current state.
 
         :param state: The state of this PaymentTerminalLocation.
         :type: PaymentTerminalLocationState
@@ -188,7 +188,7 @@ class PaymentTerminalLocation:
     def version(self):
         """Gets the version of this PaymentTerminalLocation.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :return: The version of this PaymentTerminalLocation.
         :rtype: int
@@ -199,7 +199,7 @@ class PaymentTerminalLocation:
     def version(self, version):
         """Sets the version of this PaymentTerminalLocation.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :param version: The version of this PaymentTerminalLocation.
         :type: int
