@@ -191,7 +191,7 @@ class Subscriber:
     def external_id(self):
         """Gets the external_id of this Subscriber.
 
-            The external id helps to identify the entity and a subsequent creation of an entity with the same ID will not create a new entity.
+            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.
 
         :return: The external_id of this Subscriber.
         :rtype: str
@@ -202,7 +202,7 @@ class Subscriber:
     def external_id(self, external_id):
         """Sets the external_id of this Subscriber.
 
-            The external id helps to identify the entity and a subsequent creation of an entity with the same ID will not create a new entity.
+            A client generated nonce which identifies the entity to be created. Subsequent creation requests with the same external ID will not create new entities but return the initially created entity instead.
 
         :param external_id: The external_id of this Subscriber.
         :type: str
@@ -214,7 +214,7 @@ class Subscriber:
     def id(self):
         """Gets the id of this Subscriber.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :return: The id of this Subscriber.
         :rtype: int
@@ -225,7 +225,7 @@ class Subscriber:
     def id(self, id):
         """Sets the id of this Subscriber.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :param id: The id of this Subscriber.
         :type: int
@@ -260,7 +260,7 @@ class Subscriber:
     def linked_space_id(self):
         """Gets the linked_space_id of this Subscriber.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :return: The linked_space_id of this Subscriber.
         :rtype: int
@@ -271,7 +271,7 @@ class Subscriber:
     def linked_space_id(self, linked_space_id):
         """Sets the linked_space_id of this Subscriber.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :param linked_space_id: The linked_space_id of this Subscriber.
         :type: int
@@ -306,7 +306,7 @@ class Subscriber:
     def planned_purge_date(self):
         """Gets the planned_purge_date of this Subscriber.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :return: The planned_purge_date of this Subscriber.
         :rtype: datetime
@@ -317,7 +317,7 @@ class Subscriber:
     def planned_purge_date(self, planned_purge_date):
         """Sets the planned_purge_date of this Subscriber.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :param planned_purge_date: The planned_purge_date of this Subscriber.
         :type: datetime
@@ -377,7 +377,7 @@ class Subscriber:
     def state(self):
         """Gets the state of this Subscriber.
 
-            
+            The object's current state.
 
         :return: The state of this Subscriber.
         :rtype: CreationEntityState
@@ -388,7 +388,7 @@ class Subscriber:
     def state(self, state):
         """Sets the state of this Subscriber.
 
-            
+            The object's current state.
 
         :param state: The state of this Subscriber.
         :type: CreationEntityState
@@ -400,7 +400,7 @@ class Subscriber:
     def version(self):
         """Gets the version of this Subscriber.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :return: The version of this Subscriber.
         :rtype: int
@@ -411,7 +411,7 @@ class Subscriber:
     def version(self, version):
         """Sets the version of this Subscriber.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :param version: The version of this Subscriber.
         :type: int
