@@ -228,7 +228,7 @@ class SubscriptionProductVersion:
     def id(self):
         """Gets the id of this SubscriptionProductVersion.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :return: The id of this SubscriptionProductVersion.
         :rtype: int
@@ -239,7 +239,7 @@ class SubscriptionProductVersion:
     def id(self, id):
         """Sets the id of this SubscriptionProductVersion.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :param id: The id of this SubscriptionProductVersion.
         :type: int
@@ -274,7 +274,7 @@ class SubscriptionProductVersion:
     def linked_space_id(self):
         """Gets the linked_space_id of this SubscriptionProductVersion.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :return: The linked_space_id of this SubscriptionProductVersion.
         :rtype: int
@@ -285,7 +285,7 @@ class SubscriptionProductVersion:
     def linked_space_id(self, linked_space_id):
         """Sets the linked_space_id of this SubscriptionProductVersion.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :param linked_space_id: The linked_space_id of this SubscriptionProductVersion.
         :type: int
@@ -389,7 +389,7 @@ class SubscriptionProductVersion:
     def planned_purge_date(self):
         """Gets the planned_purge_date of this SubscriptionProductVersion.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :return: The planned_purge_date of this SubscriptionProductVersion.
         :rtype: datetime
@@ -400,7 +400,7 @@ class SubscriptionProductVersion:
     def planned_purge_date(self, planned_purge_date):
         """Sets the planned_purge_date of this SubscriptionProductVersion.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :param planned_purge_date: The planned_purge_date of this SubscriptionProductVersion.
         :type: datetime
@@ -506,7 +506,7 @@ class SubscriptionProductVersion:
     def state(self):
         """Gets the state of this SubscriptionProductVersion.
 
-            
+            The object's current state.
 
         :return: The state of this SubscriptionProductVersion.
         :rtype: SubscriptionProductVersionState
@@ -517,7 +517,7 @@ class SubscriptionProductVersion:
     def state(self, state):
         """Sets the state of this SubscriptionProductVersion.
 
-            
+            The object's current state.
 
         :param state: The state of this SubscriptionProductVersion.
         :type: SubscriptionProductVersionState
@@ -552,7 +552,7 @@ class SubscriptionProductVersion:
     def version(self):
         """Gets the version of this SubscriptionProductVersion.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :return: The version of this SubscriptionProductVersion.
         :rtype: int
@@ -563,7 +563,7 @@ class SubscriptionProductVersion:
     def version(self, version):
         """Sets the version of this SubscriptionProductVersion.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :param version: The version of this SubscriptionProductVersion.
         :type: int
