@@ -222,7 +222,7 @@ class SubscriptionVersion:
     def id(self):
         """Gets the id of this SubscriptionVersion.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :return: The id of this SubscriptionVersion.
         :rtype: int
@@ -233,7 +233,7 @@ class SubscriptionVersion:
     def id(self, id):
         """Sets the id of this SubscriptionVersion.
 
-            The ID is the primary key of the entity. The ID identifies the entity uniquely.
+            A unique identifier for the object.
 
         :param id: The id of this SubscriptionVersion.
         :type: int
@@ -245,7 +245,7 @@ class SubscriptionVersion:
     def language(self):
         """Gets the language of this SubscriptionVersion.
 
-            
+            The language that is linked to the object.
 
         :return: The language of this SubscriptionVersion.
         :rtype: str
@@ -256,7 +256,7 @@ class SubscriptionVersion:
     def language(self, language):
         """Sets the language of this SubscriptionVersion.
 
-            
+            The language that is linked to the object.
 
         :param language: The language of this SubscriptionVersion.
         :type: str
@@ -268,7 +268,7 @@ class SubscriptionVersion:
     def linked_space_id(self):
         """Gets the linked_space_id of this SubscriptionVersion.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :return: The linked_space_id of this SubscriptionVersion.
         :rtype: int
@@ -279,7 +279,7 @@ class SubscriptionVersion:
     def linked_space_id(self, linked_space_id):
         """Sets the linked_space_id of this SubscriptionVersion.
 
-            The linked space id holds the ID of the space to which the entity belongs to.
+            The ID of the space this object belongs to.
 
         :param linked_space_id: The linked_space_id of this SubscriptionVersion.
         :type: int
@@ -291,7 +291,7 @@ class SubscriptionVersion:
     def planned_purge_date(self):
         """Gets the planned_purge_date of this SubscriptionVersion.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :return: The planned_purge_date of this SubscriptionVersion.
         :rtype: datetime
@@ -302,7 +302,7 @@ class SubscriptionVersion:
     def planned_purge_date(self, planned_purge_date):
         """Sets the planned_purge_date of this SubscriptionVersion.
 
-            The planned purge date indicates when the entity is permanently removed. When the date is null the entity is not planned to be removed.
+            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.
 
         :param planned_purge_date: The planned_purge_date of this SubscriptionVersion.
         :type: datetime
@@ -383,7 +383,7 @@ class SubscriptionVersion:
     def state(self):
         """Gets the state of this SubscriptionVersion.
 
-            
+            The object's current state.
 
         :return: The state of this SubscriptionVersion.
         :rtype: SubscriptionVersionState
@@ -394,7 +394,7 @@ class SubscriptionVersion:
     def state(self, state):
         """Sets the state of this SubscriptionVersion.
 
-            
+            The object's current state.
 
         :param state: The state of this SubscriptionVersion.
         :type: SubscriptionVersionState
@@ -498,7 +498,7 @@ class SubscriptionVersion:
     def version(self):
         """Gets the version of this SubscriptionVersion.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :return: The version of this SubscriptionVersion.
         :rtype: int
@@ -509,7 +509,7 @@ class SubscriptionVersion:
     def version(self, version):
         """Sets the version of this SubscriptionVersion.
 
-            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.
+            The version is used for optimistic locking and incremented whenever the object is updated.
 
         :param version: The version of this SubscriptionVersion.
         :type: int
